==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d1/de8/fileio__type_8h.js <==
var fileio__type_8h =
[
    [ "MAKE_FIOS_TYPE", "d1/de8/fileio__type_8h.html#ac76f193ba9c0cde921fc677d61910d31", null ],
    [ "AbstractFileType", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900", [
      [ "FT_NONE", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a5d8433cc1c68d7c1668c156648f22ffc", null ],
      [ "FT_SAVEGAME", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a6b96a17d03ea76aeba8220f5104e8d36", null ],
      [ "FT_SCENARIO", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a24a95c8897ddfef0ef57c646101ab4a9", null ],
      [ "FT_HEIGHTMAP", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a597b6dc948b7dc2ae28ee8a6b417c019", null ],
      [ "FT_INVALID", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900aab62a862db58eb6e3900d85620b2142f", null ],
      [ "FT_NUMBITS", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900aa842731d224f0e3b2e3d74dd4694d061", null ],
      [ "FT_MASK", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900ae84b6254ad6fa9a8ce0d8440f099bd66", null ]
    ] ],
    [ "DetailedFileType", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36", [
      [ "DFT_OLD_GAME_FILE", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36ae940716071381e9d0b62fbc4f6c0fe67", null ],
      [ "DFT_GAME_FILE", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a3840a232d713e1478df9cc6655279719", null ],
      [ "DFT_HEIGHTMAP_BMP", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a5db3ea29d29f0b953e31db3e2147974c", null ],
      [ "DFT_HEIGHTMAP_PNG", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a70c00d88e2efef17d65b2f1aa443424e", null ],
      [ "DFT_FIOS_DRIVE", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a2b40873f472f33553811b405d52a334c", null ],
      [ "DFT_FIOS_PARENT", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36aa1debdad5a145439b637d367a8d6c4ac", null ],
      [ "DFT_FIOS_DIR", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a73f3bad7ea3b3f969333e4cb6bbfddcd", null ],
      [ "DFT_FIOS_DIRECT", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36ac13d9238295d051959fb43c69cbf094b", null ],
      [ "DFT_INVALID", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36ab33af49da49db16ce860f7288b4e5a1f", null ]
    ] ],
    [ "FiosType", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2db", [
      [ "FIOS_TYPE_DRIVE", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba3bd4ed641f5b15b9978471f06ce9e0f1", null ],
      [ "FIOS_TYPE_PARENT", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dbaddb15a49c2cbaeb66bd732338bdd4646", null ],
      [ "FIOS_TYPE_DIR", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dbab6c66795c3ba04ca5c58464f74d8e4f8", null ],
      [ "FIOS_TYPE_DIRECT", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba690877aad5dcd91061dc34ce6f5ea922", null ],
      [ "FIOS_TYPE_FILE", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba15091368902ee003dd4e1d3e57deb439", null ],
      [ "FIOS_TYPE_OLDFILE", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba9462c3a7e46811d00e268803bd98194e", null ],
      [ "FIOS_TYPE_SCENARIO", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba6125f2368dbb907323713cace718af4e", null ],
      [ "FIOS_TYPE_OLD_SCENARIO", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba6a9bb120ecf5534fe7c400feb55eaa72", null ],
      [ "FIOS_TYPE_PNG", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dbadffd573d27dbd201245df726b08e53ce", null ],
      [ "FIOS_TYPE_BMP", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba60b3074ca3db21c92414a667c363cd44", null ],
      [ "FIOS_TYPE_INVALID", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba959e40bf899fb307b2c506cc0513c272", null ]
    ] ],
    [ "SaveLoadOperation", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1", [
      [ "SLO_CHECK", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1a1a1afde4a61dc663615ee191d5148818", null ],
      [ "SLO_LOAD", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1a4c3e119b88d3b0b990b2331fb568b517", null ],
      [ "SLO_SAVE", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1a2f71fcdc3db05a8fe030ebb2a7f869b4", null ],
      [ "SLO_INVALID", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1aacc72953fa526bc4e3bba1e2344c9cd1", null ]
    ] ],
    [ "Searchpath", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3fa", [
      [ "SP_FIRST_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faa73e62be61dfa5d5c1fbbeb060f7bc618", null ],
      [ "SP_WORKING_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faa72339bbd0180a077a46885e5bfba3842", null ],
      [ "SP_PERSONAL_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faa51870c499152e31b5d99b7269ca285ba", null ],
      [ "SP_SHARED_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faa0d8478708aa519e3ee2fda1c5369c63d", null ],
      [ "SP_BINARY_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faa483dbcbc1fce58b9b5ff92339222c1a3", null ],
      [ "SP_INSTALLATION_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faa14ffab009ed533fdb7135e6b2bfbc485", null ],
      [ "SP_APPLICATION_BUNDLE_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faab7d4d7a5665751297a951f5164acb2fb", null ],
      [ "SP_AUTODOWNLOAD_DIR", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faaceee394c97db186a9229f68ddc7955a8", null ],
      [ "NUM_SEARCHPATHS", "d1/de8/fileio__type_8h.html#a26418577e63d432116822f0f21b2a3faa7f4b87dfc5a2e399a97bc8bc396af2c3", null ]
    ] ],
    [ "Subdirectory", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6", [
      [ "BASE_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a6ff453fafe6c17fb7b1702d670336304", null ],
      [ "SAVE_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a79069f94b7e90f69b30912d347e43936", null ],
      [ "AUTOSAVE_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6abe27709f3f7c50f40c92376eefdc5b00", null ],
      [ "SCENARIO_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a6e9f94ce2d61a100c8e5b3d94ac96618", null ],
      [ "HEIGHTMAP_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6ab21167ba68787d43ad029e21161b94b8", null ],
      [ "OLD_GM_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a56583a57c29ebd5963cbb06d33499d5e", null ],
      [ "OLD_DATA_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a01affc28164fac2d612d7e4c1d8b583b", null ],
      [ "BASESET_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6af9d06fb818940df02d0657ceac3ed8e7", null ],
      [ "NEWGRF_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6ab6fe47523f2072dcf2f0105e8b42e6dc", null ],
      [ "LANG_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6ad9b9d2adb84537554c02131b0cdf75c9", null ],
      [ "AI_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a4d255a5c2d3022ff28bca5c63111fb5e", null ],
      [ "AI_LIBRARY_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a1b2ff028a39d93312934a1562e075564", null ],
      [ "GAME_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6afb741582f3f8b7f271824583f1dd9d0e", null ],
      [ "GAME_LIBRARY_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a4aad920d28547208bda9fc04843fb36c", null ],
      [ "SCREENSHOT_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a27b1f6b070e9133ee46e75621bee9bfc", null ],
      [ "NUM_SUBDIRS", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6aaae7b90d116a215ed2c82c7239cf1452", null ],
      [ "NO_DIRECTORY", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a18a7c7b05fcf4d482d2707ddd3709d7a", null ]
    ] ],
    [ "GetAbstractFileType", "d1/de8/fileio__type_8h.html#a182d34262d399935c90eb746156ae6b4", null ],
    [ "GetDetailedFileType", "d1/de8/fileio__type_8h.html#a1446e107f7b88e409a0b48a7133ca12c", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d1/de8/fileio__type_8h.js <==
var fileio__type_8h =
[
    [ "MAKE_FIOS_TYPE", "d1/de8/fileio__type_8h.html#ac76f193ba9c0cde921fc677d61910d31", null ],
    [ "AbstractFileType", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900", [
      [ "FT_NONE", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a5d8433cc1c68d7c1668c156648f22ffc", null ],
      [ "FT_SAVEGAME", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a6b96a17d03ea76aeba8220f5104e8d36", null ],
      [ "FT_SCENARIO", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a24a95c8897ddfef0ef57c646101ab4a9", null ],
      [ "FT_HEIGHTMAP", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900a597b6dc948b7dc2ae28ee8a6b417c019", null ],
      [ "FT_INVALID", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900aab62a862db58eb6e3900d85620b2142f", null ],
      [ "FT_NUMBITS", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900aa842731d224f0e3b2e3d74dd4694d061", null ],
      [ "FT_MASK", "d1/de8/fileio__type_8h.html#a61cf4063f267231346c46fe8b2efb900ae84b6254ad6fa9a8ce0d8440f099bd66", null ]
    ] ],
    [ "DetailedFileType", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36", [
      [ "DFT_OLD_GAME_FILE", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36ae940716071381e9d0b62fbc4f6c0fe67", null ],
      [ "DFT_GAME_FILE", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a3840a232d713e1478df9cc6655279719", null ],
      [ "DFT_HEIGHTMAP_BMP", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a5db3ea29d29f0b953e31db3e2147974c", null ],
      [ "DFT_HEIGHTMAP_PNG", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a70c00d88e2efef17d65b2f1aa443424e", null ],
      [ "DFT_FIOS_DRIVE", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a2b40873f472f33553811b405d52a334c", null ],
      [ "DFT_FIOS_PARENT", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36aa1debdad5a145439b637d367a8d6c4ac", null ],
      [ "DFT_FIOS_DIR", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36a73f3bad7ea3b3f969333e4cb6bbfddcd", null ],
      [ "DFT_FIOS_DIRECT", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36ac13d9238295d051959fb43c69cbf094b", null ],
      [ "DFT_INVALID", "d1/de8/fileio__type_8h.html#acd93ba46be4d6582d2cc459989de6f36ab33af49da49db16ce860f7288b4e5a1f", null ]
    ] ],
    [ "FiosType", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2db", [
      [ "FIOS_TYPE_DRIVE", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba3bd4ed641f5b15b9978471f06ce9e0f1", null ],
      [ "FIOS_TYPE_PARENT", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dbaddb15a49c2cbaeb66bd732338bdd4646", null ],
      [ "FIOS_TYPE_DIR", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dbab6c66795c3ba04ca5c58464f74d8e4f8", null ],
      [ "FIOS_TYPE_DIRECT", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba690877aad5dcd91061dc34ce6f5ea922", null ],
      [ "FIOS_TYPE_FILE", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba15091368902ee003dd4e1d3e57deb439", null ],
      [ "FIOS_TYPE_OLDFILE", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba9462c3a7e46811d00e268803bd98194e", null ],
      [ "FIOS_TYPE_SCENARIO", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba6125f2368dbb907323713cace718af4e", null ],
      [ "FIOS_TYPE_OLD_SCENARIO", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba6a9bb120ecf5534fe7c400feb55eaa72", null ],
      [ "FIOS_TYPE_PNG", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dbadffd573d27dbd201245df726b08e53ce", null ],
      [ "FIOS_TYPE_BMP", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba60b3074ca3db21c92414a667c363cd44", null ],
      [ "FIOS_TYPE_INVALID", "d1/de8/fileio__type_8h.html#a80674279d60bdd7bdb06638143b2a2dba959e40bf899fb307b2c506cc0513c272", null ]
    ] ],
    [ "SaveLoadOperation", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1", [
      [ "SLO_CHECK", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1a1a1afde4a61dc663615ee191d5148818", null ],
      [ "SLO_LOAD", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1a4c3e119b88d3b0b990b2331fb568b517", null ],
      [ "SLO_SAVE", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1a2f71fcdc3db05a8fe030ebb2a7f869b4", null ],
      [ "SLO_INVALID", "d1/de8/fileio__type_8h.html#aa3546fc99988993a160673f15df5f8e1aacc72953fa526bc4e3bba1e2344c9cd1", null ]
    ] ],
    [ "Searchpath", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210", [
      [ "SP_FIRST_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a73e62be61dfa5d5c1fbbeb060f7bc618", null ],
      [ "SP_WORKING_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a72339bbd0180a077a46885e5bfba3842", null ],
      [ "SP_PERSONAL_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a51870c499152e31b5d99b7269ca285ba", null ],
      [ "SP_SHARED_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a0d8478708aa519e3ee2fda1c5369c63d", null ],
      [ "SP_BINARY_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a483dbcbc1fce58b9b5ff92339222c1a3", null ],
      [ "SP_INSTALLATION_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a14ffab009ed533fdb7135e6b2bfbc485", null ],
      [ "SP_APPLICATION_BUNDLE_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210ab7d4d7a5665751297a951f5164acb2fb", null ],
      [ "SP_AUTODOWNLOAD_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210aceee394c97db186a9229f68ddc7955a8", null ],
      [ "SP_AUTODOWNLOAD_PERSONAL_DIR", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a517e840d61f81ac160c25342cfb0678a", null ],
      [ "SP_AUTODOWNLOAD_PERSONAL_DIR_XDG", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a2bff11370ba0d06e6ca417d1c8672479", null ],
      [ "NUM_SEARCHPATHS", "d1/de8/fileio__type_8h.html#ad3cffccdb79272f7e64dd5dac39b9210a7f4b87dfc5a2e399a97bc8bc396af2c3", null ]
    ] ],
    [ "Subdirectory", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6", [
      [ "BASE_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a6ff453fafe6c17fb7b1702d670336304", null ],
      [ "SAVE_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a79069f94b7e90f69b30912d347e43936", null ],
      [ "AUTOSAVE_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6abe27709f3f7c50f40c92376eefdc5b00", null ],
      [ "SCENARIO_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a6e9f94ce2d61a100c8e5b3d94ac96618", null ],
      [ "HEIGHTMAP_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6ab21167ba68787d43ad029e21161b94b8", null ],
      [ "OLD_GM_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a56583a57c29ebd5963cbb06d33499d5e", null ],
      [ "OLD_DATA_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a01affc28164fac2d612d7e4c1d8b583b", null ],
      [ "BASESET_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6af9d06fb818940df02d0657ceac3ed8e7", null ],
      [ "NEWGRF_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6ab6fe47523f2072dcf2f0105e8b42e6dc", null ],
      [ "LANG_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6ad9b9d2adb84537554c02131b0cdf75c9", null ],
      [ "AI_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a4d255a5c2d3022ff28bca5c63111fb5e", null ],
      [ "AI_LIBRARY_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a1b2ff028a39d93312934a1562e075564", null ],
      [ "GAME_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6afb741582f3f8b7f271824583f1dd9d0e", null ],
      [ "GAME_LIBRARY_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a4aad920d28547208bda9fc04843fb36c", null ],
      [ "SCREENSHOT_DIR", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a27b1f6b070e9133ee46e75621bee9bfc", null ],
      [ "NUM_SUBDIRS", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6aaae7b90d116a215ed2c82c7239cf1452", null ],
      [ "NO_DIRECTORY", "d1/de8/fileio__type_8h.html#ae682492d3a9c6df2e605b375e91fb7e6a18a7c7b05fcf4d482d2707ddd3709d7a", null ]
    ] ],
    [ "GetAbstractFileType", "d1/de8/fileio__type_8h.html#a182d34262d399935c90eb746156ae6b4", null ],
    [ "GetDetailedFileType", "d1/de8/fileio__type_8h.html#a1446e107f7b88e409a0b48a7133ca12c", null ]
];
